@@ -1,4 +1,4 @@
-use crate::model::{Method, MethodImpl, MethodPayableMetadata, PublicRole};
+use crate::model::{Method, MethodImpl, MethodPayableMetadata, PublicRole, TraitProperties};
 
 use super::{
     attributes::extract_doc,
@@ -18,7 +18,7 @@ pub struct MethodAttributesPass1 {
     pub only_owner: bool,
 }
 
-pub fn process_method(m: &syn::TraitItemMethod) -> Method {
+pub fn process_method(m: &syn::TraitItemMethod, trait_attributes: &TraitProperties) -> Method {
     let method_args = extract_method_args(m);
 
     let implementation = if let Some(body) = m.default.clone() {
@@ -30,7 +30,7 @@ pub fn process_method(m: &syn::TraitItemMethod) -> Method {
     let mut first_pass_data = MethodAttributesPass1 {
         method_name: m.sig.ident.to_string(),
         payable: MethodPayableMetadata::NotPayable,
-        only_owner: false,
+        only_owner: trait_attributes.only_owner,
     };
     let mut first_pass_unprocessed_attributes = Vec::new();
 
