@@ -9,6 +9,7 @@ mod parse_util;
 mod payable_parse;
 mod split_path;
 mod supertrait_parse;
+mod trait_argument_parse;
 
 pub use argument_parse::*;
 pub use contract_trait_parse::*;
@@ -17,3 +18,4 @@ pub use method_parse::*;
 pub use payable_parse::*;
 pub use split_path::*;
 pub use supertrait_parse::*;
+pub use trait_argument_parse::*;
